albumentations
==============

albumentations is a fast image augmentation library and easy to use wrapper around other libraries.

Features
--------
* Great fast augmentations based on highly-optimized OpenCV library.
* Super simple yet powerful interface for different tasks like (segmentation, detection, etc).
* Easy to customize.
* Easy to add other frameworks.

Project info
------------
* GitHub repository: https://github.com/albu/albumentations
* License: MIT

Installation
------------
You can use **pip** to install the latest version from GitHub:

::

    pip install -U git+https://github.com/albu/albumentations

.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   contributing
   api/index
